<?php
/**
 * A factory class for producer
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ProducerFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton producer instance. If no instance is found, it fill
	 * be generated and stored in registry, else the producer from the
	 * registry will be returned.
	 *
	 * @param	$configEntry		A configuration entry naming the real class' name
	 * @parasm	$producerType		Type of the producer, can be 'key', 'test_unit', etc.
	 * @return	$producerInstance	A producer instance
	 */
	public static final function createProducerInstance ($configEntry, $producerType) {
		// If there is no producer?
		if (Registry::getRegistry()->instanceExists($producerType . '_producer')) {
			// Get producer from registry
			$producerInstance = Registry::getRegistry()->getInstance($producerType . '_producer');
		} else {
			// Get the producer instance
			$producerInstance = self::createObjectByConfiguredName($configEntry);

			// Add it to the registry
			Registry::getRegistry()->addInstance($producerType . '_producer', $producerInstance);
		}

		// Return the instance
		return $producerInstance;
	}
}

// [EOF]
?>
