<?php
/**
 * A factory class for URL sources
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class UrlSourceObjectFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton (registry-based) UrlSource instance
	 *
	 * @param	$taskInstance		An instance of a class with an Taskable interface
	 * @return	$sourceInstance		An instance of a UrlSource class
	 */
	public static final function createUrlSourceInstance (Taskable $taskInstance) {
		// Get new factory instance
		$factoryInstance = new UrlSourceObjectFactory();

		// Get task handler instance
		$handlerInstance = Registry::getRegistry()->getInstance('task_handler');

		// Get source type by looking for given task instance in task handler
		$sourceType = $handlerInstance->searchTask($taskInstance);

		// Only let registered tasks pass
		assert(!empty($sourceType));

		// If there is no handler?
		if (Registry::getRegistry()->instanceExists('source_' . $sourceType)) {
			// Get handler from registry
			$sourceInstance = Registry::getRegistry()->getInstance('source_' . $sourceType);
		} else {
			// Get the source instance
			$sourceInstance = ObjectFactory::createObjectByConfiguredName($sourceType . '_class');

			// Add it to the registry
			Registry::getRegistry()->addInstance('source_' . $sourceType, $sourceInstance);
		}

		// Return the instance
		return $sourceInstance;
	}
}

// [EOF]
?>
