<?php
/**
 * A factory class for cruncher states
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2011 - 2014 Cruncher Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CruncherStateFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of a configurable cruncher state and sets it in the
	 * given cruncher instance.
	 *
	 * @param	$stateName			Name of the state
	 * @param	$cruncherInstance	A CruncherHelper class instance
	 * @return	$stateInstance		A Stateable class instance
	 */
	public static final function createCruncherStateInstanceByName ($stateName) {
		// Then construct the class' configuraton entry
		$className = 'cruncher_' . $stateName . '_state_class';

		// Get cruncher instance from registry
		$cruncherInstance = Registry::getRegistry()->getInstance('cruncher');

		// Get a class from that configuration entry
		$stateInstance = self::createObjectByConfiguredName($className);

		// Debug message
		self::createDebugInstance(__CLASS__)->debugOutput('CRUNCHER-STATE-FACTORY[' . __METHOD__ . ':' . __LINE__ . ']: Cruncher state has changed from ' . $cruncherInstance->getPrintableState() . ' to ' . $stateInstance->getStateName() . '.');

		// Once we have that state, set it in the cruncher instance
		$cruncherInstance->setStateInstance($stateInstance);

		// For any purposes, return the state instance
		return $stateInstance;
	}
}

// [EOF]
?>
